/*
 *    GSFile.java
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.util;

import java.io.File; 
import org.apache.soap.encoding.soapenc.Base64;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.IOException;

/**
 * GSFiles - utility class for Greenstone.
 *
 * contains File creation methods.
 *
 * @author <a href="mailto:kjdon@cs.waikato.ac.nz">Katherine Don</a>
 * @version $Revision: 3284 $
 * @see File
 */
public class GSFile {

    /** creates a File for the site config file */
    static public File siteConfigFile(String site_home) {
	return new File(site_home + File.separatorChar+"sitecfg.xml");

    }

    /** creates a File for the collection directory  */
    static public File collectDirFile(String site_home) {
	return new File(site_home+File.separatorChar+"collect");
    }
    
    
    /** creates a File for the collection config file */
    static public File collectionConfigFile(String site_home, 
					    String collection_name) {
	return new File(site_home+File.separatorChar+"collect"+
			File.separatorChar+collection_name+
			File.separatorChar+"etc"+
			File.separatorChar+"collectcfg.xml");

    }

    /** creates a File for the collection build config file */
    static public File collectionBuildConfigFile(String site_home, 
						 String collection_name ) {
	return new File(site_home+File.separatorChar+"collect"+
			File.separatorChar+collection_name+
			File.separatorChar+"index"+
			File.separatorChar+"buildcfg.xml");
    }

    /** returns the directory for XML Transforms */
    static public String xmlTransformDir(String gsdl_home) {
	return gsdl_home+File.separatorChar+"transform";
    }

    /** returns the base directory name for a collection */	 
    static public String collectionBaseDir(String site_home,
					   String collection_name) {
	return site_home+File.separatorChar+"collect"+
	    File.separatorChar+collection_name;
    }

    /** returns the text path (for doc retrieval) relative to collectionBaseDir */
    static public String collectionTextPath(String collection_name) {
	return "index"+File.separatorChar+"text"+File.separatorChar+
	    collection_name;
    }

    /** returns the index path (for querying) relative to collectionBaseDir */
    static public String collectionIndexPath(String collection_name,
					     String index_name) {
	return "index"+File.separatorChar+index_name+File.separatorChar+
	    collection_name;
    }

    /** returns an absolute path for an associated file */
    static public String assocFileAbsolutePath(String site_home,
					       String collection_name,
					       String assoc_file_path,
					       String filename) {
	return collectionBaseDir(site_home, collection_name)+
	    File.separatorChar+"index"+File.separatorChar+
	    "assoc"+File.separatorChar+assoc_file_path+
	    File.separatorChar+filename;
    }
					      
    static public String base64EncodeFromFile(String in_filename) {
	byte [] data=null;
	try {
	    data = readFile(in_filename);
	} catch (Exception e) {
	    System.out.println("couldn't read the file");
	}
	String encodedString = Base64.encode(data);
	return encodedString;

    }
    static public boolean base64DecodeToFile(String data, String out_filename) {
	try {
	    byte[] buffer=Base64.decode(data);
	    writeFile(buffer, out_filename);
	    
	} catch (Exception e) {
	    System.err.println("file opening/closing errors"+e.getMessage());
	    return false;
	}
	return true;
	
    }

    public static byte[] readFile(String filename) throws IOException {
	File file = new File(filename);
	BufferedInputStream bis = new BufferedInputStream(new
	    FileInputStream(file));
	int bytes = (int) file.length();
	byte[] buffer = new byte[bytes];
	int readBytes = bis.read(buffer);
	bis.close();
	return buffer;
    }
    public static void writeFile(byte [] buffer, String filename) throws IOException {
	File file = new File(filename);
	BufferedOutputStream bos = new BufferedOutputStream(new
	    FileOutputStream(file));
	bos.write(buffer);
	bos.close();
    }

}
